OscAddress class

Represents an OSC Address as defined in the OSC specification.

An OSC Address is a symbolic name giving the full path to an OSC Method in an OSC Address Space. It begins with '/' and contains the names of all containers and the method, separated by forward slashes.

Constructors

OscAddress(String address)
Creates an OSC Address from a string representation

Properties

containerPath List<String>
Returns the container path (all parts except the last)
no setter
depth int
Returns the depth of this address (number of parts)
no setter
hashCode int
The hash code for this object.
no setteroverride
isRoot bool
Returns true if this address is the root address ('/')
no setter
methodName String?
Returns the method name (last part of the address)
no setter
parent OscAddress?
Returns the parent address (without the method name)
no setter
parts List<String>
Returns the parts of this address (container names and method name)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

child(String name) OscAddress
Creates a child address by appending a name
compareTo(OscAddress other) int
Compares two addresses lexicographically
isChildOf(OscAddress parent) bool
Returns true if this address is a direct child of the given parent
isDescendantOf(OscAddress ancestor) bool
Returns true if this address is a descendant of the given ancestor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the string representation of this address
override

Operators

operator ==(Object other) bool
The equality operator.
override