OscDecoder class

Decodes OSC atomic data types from their binary representation

Constructors

OscDecoder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeBlob(Uint8List bytes, int offset) DecodeResult<Uint8List>
Decodes an OSC-blob with size prefix and 32-bit alignment padding
decodeChar(Uint8List bytes, int offset) DecodeResult<String>
Decodes an ASCII character from a 32-bit big-endian value (extended type)
decodeColor(Uint8List bytes, int offset) DecodeResult<int>
Decodes a 32-bit RGBA color value from big-endian format (extended type)
decodeDouble64(Uint8List bytes, int offset) DecodeResult<double>
Decodes a 64-bit IEEE 754 double precision floating point number from big-endian format (extended type)
decodeFalse(Uint8List bytes, int offset) DecodeResult<bool>
Decodes False type (no data allocated) (extended type)
decodeFloat32(Uint8List bytes, int offset) DecodeResult<double>
Decodes a 32-bit IEEE 754 floating point number from big-endian format
decodeInfinitum(Uint8List bytes, int offset) DecodeResult<double>
Decodes Infinitum type (no data allocated) (extended type)
decodeInt32(Uint8List bytes, int offset) DecodeResult<int>
Decodes a 32-bit signed integer from big-endian format
decodeInt64(Uint8List bytes, int offset) DecodeResult<int>
Decodes a 64-bit signed integer from big-endian format (extended type)
decodeMidi(Uint8List bytes, int offset) DecodeResult<List<int>>
Decodes a 4-byte MIDI message (extended type)
decodeNil(Uint8List bytes, int offset) DecodeResult<void>
Decodes Nil type (no data allocated) (extended type)
decodeString(Uint8List bytes, int offset) DecodeResult<String>
Decodes an OSC-string with null termination and 32-bit alignment padding
decodeTimeTag(Uint8List bytes, int offset) DecodeResult<OscTimeTag>
Decodes an OSC time tag from a 64-bit big-endian value
decodeTrue(Uint8List bytes, int offset) DecodeResult<bool>
Decodes True type (no data allocated) (extended type)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited