OscPacketEvent class

Constructors

OscPacketEvent(OscPacket packet, {required InternetAddress remoteAddress, required int remotePort, required DateTime timestamp})
Creates an event for a received OSC packet with details about the source and timestamp
const

Properties

asBundle OscBundle
Casts the packet to OscBundle if it is a bundle, otherwise throws
no setter
asMessage OscMessage
Casts the packet to OscMessage if it is a message, otherwise throws
no setter
hashCode int
The hash code for this object.
no setterinherited
isBundle bool
Convenience getters for packet type
no setter
isMessage bool
Convenience getters for packet type
no setter
packet OscPacket
The decoded OSC packet
final
remoteAddress InternetAddress
The remote address the packet was received from
final
remotePort int
The remote port the packet was received from
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
The timestamp when the packet was received
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited