isBound property
bool
get
isBound
Returns true if the socket is bound and ready for communication
Implementation
bool get isBound => _socket != null;
Returns true if the socket is bound and ready for communication
bool get isBound => _socket != null;